### Statistical analysis for individual variability in response to social stress manuscript - 2020 ###
### Written by Emeline Nogues in R version 3.3.2 -- "Sincere Pumpkin Patch" ###

library(base)
library(graphics)
library(nlme)

### Import dataset
data1=read.csv("Supplementary_Data_1.csv",header=T, sep=";", dec=".")

############################################################################

### Creating the variable ENGAGEMENT
# All models with engagement (independent variable) did not meet linearity assumption
# Engagement is log transformed to satisfy this assumption
Engagement=log(data1$Disp_Feed_I+data1$Disp_Stall_I+data1$Disp_Alley_I+data1$Fights)
boxplot(Engagement)

### Creating the variable AVOIDANCE
boxplot(data1$Avoidances)
# Avoidances have one extreme value (384 avoidances for heifer 8019; 2nd highest value is 116)
# We replace 8019's avoidances true value by the 2nd highest value +1
# Please note: results from the models are similar whether 8019 is included with her true value, with the capped value, or excluded
Avoidance=replace(data1$Avoidances, data1$Avoidances>116, 117)
boxplot(Avoidance)

############################################################################

### RELATION BETWEEN THE TWO BEHAVIOURAL PATTERNS
a0=lme(Avoidance~Engagement, random=~1|Group, data=data1)
hist(residuals(a0))
summary(a0)
anova.lme(a0)
plot(Avoidance~Engagement)
# F(1,21) = 6.34 ; beta = -12.91 ; p = 0.02
# More engaged heifers were significantly less avoidant

############################################################################

### Linear mixed-effects model with time spent feeding as a function of engagement
a1=lme(Pct_Feeding~Engagement, random=~1|Group, data=data1)
hist(residuals(a1)) # positively skewed
a1=lme(log(Pct_Feeding)~Engagement, random=~1|Group, data=data1) # transformation
hist(residuals(a1))
summary(a1)
anova.lme(a1)
plot(data1$Pct_Feeding~Engagement)
# F(1,21) = 10.20 ; beta = 0.20 ; p = 0.0044
# More engaged heifers spent significantly more time feeding

### Linear mixed-effects model with time spent resting as a function of engagement
a2=lme(Pct_Resting~Engagement, random=~1|Group, data=data1)
hist(residuals(a2))
summary(a2)
anova.lme(a2)
plot(data1$Pct_Resting~Engagement)
# F(1,21) = 0.068 ; beta = 0.39 ; p = 0.80
# No significant relationship between engagement and time spent resting

### Linear mixed-effects model with synchronization while feeding as a function of engagement
a3=lme(Sync_Feeding~Engagement, random=~1|Group, data=data1)
hist(residuals(a3)) # negatively skewed
a3=lme((Sync_Feeding^2)~Engagement, random=~1|Group, data=data1) # transformation
hist(residuals(a3))
summary(a3)
anova.lme(a3)
plot(data1$Sync_Feeding~Engagement)
# F(1,21) = 0.87 ; beta = 1.60 ; p = 0.36
# No significant relationship between engagement and synchronization while feeding

### Linear mixed-effects model with synchronization while resting as a function of engagement
a4=lme(Sync_Resting~Engagement, random=~1|Group, data=data1)
hist(residuals(a4))
summary(a4)
anova.lme(a4)
plot((data1$Sync_Resting)~Engagement)
# F(1,21) = 3.25 ; beta = 0.19 ; p = 0.086
# More engaged heifers tended to be more synchronized while resting

############################################################################

### Linear mixed-effects model with time spent feeding as a function of avoidance
a5=lme(Pct_Feeding~Avoidance, random=~1|Group, data=data1)
hist(residuals(a5))
summary(a5)
anova.lme(a5)
plot(data1$Pct_Feeding~Avoidance)
# F(1,21) = 13.51 ; beta = -0.047 ; p = 0.0014
# More avoidant heifers spent significantly less time feeding

### Linear mixed-effects model with time spent resting as a function of avoidance
a6=lme(Pct_Resting~Avoidance, random=~1|Group, data=data1)
hist(residuals(a6))
summary(a6)
anova.lme(a6)
plot(data1$Pct_Resting~Avoidance)
# F(1,21) = 8.017 ; beta = -0.11 ; p = 0.01
# More avoidant heifers spent significantly less time resting

### Linear mixed-effects model with synchronization while feeding as a function of avoidance
a7=lme(Sync_Feeding~Avoidance, random=~1|Group, data=data1)
hist(residuals(a7))
summary(a7)
anova.lme(a7)
plot(data1$Sync_Feeding~Avoidance)
# F(1,21) = 11.51 ; beta = -0.021 ; p = 0.0027
# More avoidant heifers were significantly less synchronized while feeding

### Linear mixed-effects model with synchronization while resting as a function of avoidance
a8=lme(Sync_Resting~Avoidance, random=~1|Group, data=data1)
hist(residuals(a8))
summary(a8)
anova.lme(a8)
plot(data1$Sync_Resting~Avoidance)
# F(1,21) = 0.87 ; beta = -0.0031 ; p = 0.36
# No significant relationship between avoidance and synchronization while resting
